@@ -6,9 +6,9 @@ Read in the financial from the model dictionary
 import confuse  # type: ignore
 import pandas as pd  # type: ignore # noqa: F401
 
-from data import Data
-from financial import Financial
-from log import Log
+from .data import Data  # type: ignore
+from .financial import Financial  # type: ignore
+from .log import Log  # type: ignore
 
 
 class FinancialDict(Financial):
