@@ -212,7 +212,7 @@ class Compose:
         )
 
         parser.add_argument(
-            "--config", default="config/default", help="Select path to config.yaml"
+            "--config", default="restart/config/default", help="Select path to config.yaml"
         )
 
         parser.add_argument("--output", "-o", help="Write results to CSV file")
