@@ -9,13 +9,14 @@ from typing import Dict, List, Optional, Tuple
 import confuse  # type: ignore
 import numpy as np  # type: ignore
 import pandas as pd  # type: ignore
+from restart_datasets import data  # type: ignore
 
-from data import Data
-from filtermodel import Filter
-from load_csv import LoadCSV
-from log import Log
-from population import Population
-from util import datetime_to_code, load_dataframe
+from .data import Data  # type: ignore
+from .filtermodel import Filter  # type: ignore
+from .load_csv import LoadCSV  # type: ignore
+from .log import Log  # type: ignore
+from .population import Population  # type: ignore
+from .util import datetime_to_code, load_dataframe  # type: ignore
 
 
 class PopulationOES(Population):
@@ -37,6 +38,7 @@ class PopulationOES(Population):
         self,
         config: confuse.Configuration,
         filt: Filter,
+        data_dir: str = None,
         log_root: Optional[Log] = None,
     ):
         """Initialize.
@@ -60,62 +62,56 @@ class PopulationOES(Population):
 
         self.subpop = filt.subpop
         self.codes: list
+        self.data_dir = data_dir
 
-        self.load_data(config, self.location)
+        self._load_data(config, self.location)
 
-    def load_data(self, config, location):
+    def _load_data(self, config, location):
         """Do most of the initializing here.
 
         That way the stuff we don't want passed is hidden.
         """
-        # extract the dataframes we need from the input files
-        if config is not None:
-            source = config["Paths"].get()
-            source = LoadCSV(source=source).data
-            oes_df = load_dataframe(
-                os.path.join(source["Root"], source["OES"])
-            )
-            code_df = self.format_code(
-                load_dataframe(os.path.join(source["Root"], source["CODE"]))
-            )
-            pop_df = load_dataframe(
-                os.path.join(source["Root"], source["POP"])
-            )
-            xls_df = self.format_map(
-                load_dataframe(os.path.join(source["Root"], source["XLS"]))
-            )
-
+        code_df = self._format_code(data.list1_2020())
+        pop_df = data.co_est2019_alldata()
+        xls_df = self._format_map(data.covid_surge_who())
         # initialize unsliced dataframe from oes data
         if location["county"] is None and location["state"] is None:
-            df = self.create_country_df(oes_df)
+            oes_df = data.us()
+            df = self._create_country_df(oes_df)
         elif location["county"] is not None and location["state"] is not None:
-            location["county"] = location["county"]
-            df = self.create_county_df(location, oes_df, code_df, pop_df)
+            oes_df = data.counties()
+            df = self._create_county_df(location, oes_df, code_df, pop_df)
         else:
-            df = self.create_state_df(location, oes_df)
+            # oes_df = getattr(data, location["state"])
+            st = location["state"].title().replace(" ", "")
+            oes_df = eval(f"data.{st}()")  # nosec
+            df = self._create_state_df(location, oes_df)
 
         # filter the population
         if self.subpop == "healthcare":
-            df = self.health_filter(df)
+            df = self._health_filter(df)
 
         elif self.subpop == "wa_tier2_opt1":
-            df = self.wa_tier2_opt1_filter(df)
+            df = self._wa_tier2_opt1_filter(df)
 
         elif self.subpop == "wa_tier2_opt2":
-            df = self.wa_tier2_opt2_filter(df)
+            df = self._wa_tier2_opt2_filter(df)
+
+        elif self.subpop == "wa_groupings":
+            df = self._wa_public_safety_filter(df)
 
         # the actual data passed onto the model
-        self.pop_detail_df = self.drop_code(df)
+        self.pop_detail_df = self._drop_code(df)
         self.population_pP_tr = Data(
             "population_pP_tr",
             config,
             log_root=self.log_root,
             p_index=list(self.pop_detail_df.index),
             P_index=["Size"],
-            array=self.drop_code(df).to_numpy(),
+            array=self._drop_code(df).to_numpy(),
         )
 
-        pop_to_burn_df = self.pop_to_burn_rate(df, xls_df)
+        pop_to_burn_df = self._pop_to_burn_rate(df, xls_df)
         self.pop_demand_per_unit_map_pd_um: Data = Data(
             "pop_demand_per_unit_map_pd_um",
             config,
@@ -124,22 +120,16 @@ class PopulationOES(Population):
             array=pop_to_burn_df.to_numpy(),
         )
 
-        self.set_essential(xls_df, config)
-        # detail_pd_arr = detail_pd_df["Size"].to_numpy()
-        # self.pop_demand_per_unit_map_pd_um: Data = self.pop_to_burn_rate(
-        #         df,
-        #         map_df
-        # )
-        # map_labs, map_arr = self.create_map(df, map_df)
+        if self.subpop != "wa_groupings":
+            self._set_essential(xls_df, config)
+        else:
+            self.pop_to_popsum1_per_unit_map_pp1_us = Data(
+                "pop_to_popsum1_per_unit_map_pp1_us",
+                config,
+                log_root=self.log_root,
+            )
 
-        # load into dictionary
-        # df_dict = {}
-        # df_dict["detail_pd_df"] = detail_pd_df
-        # df_dict["detail_pd_arr"] = detail_pd_arr
-        # df_dict["map_labs"] = map_labs
-        # df_dict["map_arr"] = map_arr
-
-    def format_code(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _format_code(self, df: pd.DataFrame) -> pd.DataFrame:
         """Perform dataframe transformations specific to list1_2020.xls.
 
         Args:
@@ -148,7 +138,7 @@ class PopulationOES(Population):
         Returns:
             A transformed dataframe to match the format needed for this project
         """
-        # Specify columns to bypass issues with underlining in original excel
+        # specify columns to bypass issues with underlining in original excel
         df.columns = [
             "CBSA Code",
             "MDC Code",
@@ -190,7 +180,7 @@ class PopulationOES(Population):
 
         return df
 
-    def format_map(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _format_map(self, df: pd.DataFrame) -> pd.DataFrame:
         """Manually slice the excel model to get protection level mappings.
 
         Args:
@@ -200,8 +190,6 @@ class PopulationOES(Population):
             The dataframe sliced to give the mappings
         """
         # manually redo indexing and select the rows we need
-
-        # TODO: need new sheet that isn't precariously sliced like this
         DF_COLUMNS = 2528
         DF_START = 2529
         DF_END = 3303
@@ -217,7 +205,7 @@ class PopulationOES(Population):
         df = df.dropna(axis="rows").reset_index(drop=True)
         return df
 
-    def pop_to_burn_rate(
+    def _pop_to_burn_rate(
         self, df: pd.DataFrame, map_df: pd.DataFrame
     ) -> Tuple[list, np.ndarray]:
         """Generate mappings for OCC codes and population levels.
@@ -259,7 +247,7 @@ class PopulationOES(Population):
 
         return pop_to_level_df
 
-    def find_code(self, location: Dict, code_df: pd.DataFrame) -> int:
+    def _find_code(self, location: Dict, code_df: pd.DataFrame) -> int:
         """Finds the MSA code of given county.
 
         Args:
@@ -278,7 +266,7 @@ class PopulationOES(Population):
             ]["CBSA Code"].iloc[0]
         )
 
-    def calculate_proportions(
+    def _calculate_proportions(
         self,
         code: int,
         location: Dict,
@@ -299,12 +287,12 @@ class PopulationOES(Population):
         if pop_df is None:
             raise ValueError(f"{code_df=} should not be None")
 
-        # List the counties in the same MSA code as cty_name
+        # list the counties in the same MSA code as cty_name
         counties = list(
             code_df[code_df["CBSA Code"] == str(code)]["County Equivalent"]
         )
 
-        # Construct dictionary mapping county names to constituent populations
+        # construct dictionary mapping county names to constituent populations
         populations = {}
         for county in counties:
             pop = int(
@@ -315,13 +303,13 @@ class PopulationOES(Population):
             )
             populations[county] = pop
 
-        # Calculate total population in MSA code
+        # calculate total population in MSA code
         total_pop = sum(populations.values())
 
-        # Divide individual county population by total MSA population
+        # divide individual county population by total MSA population
         return populations[location["county"]] / total_pop
 
-    def load_county(
+    def _load_county(
         self,
         location: Dict,
         oes_df: pd.DataFrame,
@@ -339,10 +327,10 @@ class PopulationOES(Population):
             df: Sliced OES dataframe
         """
         # find county MSA CODE
-        code = self.find_code(location, code_df)
+        code = self._find_code(location, code_df)
 
         # calculate proportion of MSA code's residents living in county
-        proportion = self.calculate_proportions(
+        proportion = self._calculate_proportions(
             code, location, code_df, pop_df
         )
 
@@ -356,7 +344,10 @@ class PopulationOES(Population):
 
         return proportion, df
 
-    def load_state(self, location: Dict, oes_df: pd.DataFrame) -> pd.DataFrame:
+    # TODO: don't need this function anymore
+    def _load_state(
+        self, location: Dict, oes_df: pd.DataFrame
+    ) -> pd.DataFrame:
         """Slice the OES data by state for further processing downstream.
 
         Args:
@@ -365,32 +356,26 @@ class PopulationOES(Population):
         Returns:
             df: Sliced OES dataframe
         """
-        # slice OES dataframe by state
-        col_list = ["occ_code", "occ_title", "o_group", "tot_emp"]
-        df = oes_df[(oes_df["area_title"] == location["state"])][col_list]
-
         # replace placeholders with 0
-        df = df.replace(to_replace="**", value=0)
-
+        df = oes_df.replace(to_replace="**", value=0)
+        df.drop(["Unnamed: 0"], axis=1, inplace=True)
         return df
 
-    def load_country(self, oes_df: pd.DataFrame) -> pd.DataFrame:
+    def _load_country(self, oes_df: pd.DataFrame) -> pd.DataFrame:
         """Get the OES data for the whole country.
 
         The default setting for OES population
         """
         # slice OES dataframe by the whole county
         col_list = ["occ_code", "occ_title", "o_group", "tot_emp", "naics"]
-        df = oes_df[
-            (oes_df["area_title"] == "U.S.") & (oes_df["naics"] == "000000")
-        ][col_list]
+        df = oes_df[col_list]
         df = df.drop(["naics"], axis=1)
         # replace placeholders with 0
         df = df.replace(to_replace="**", value=0)
 
         return df
 
-    def fill_uncounted(
+    def _fill_uncounted(
         self, major: pd.DataFrame, detailed: pd.DataFrame
     ) -> pd.DataFrame:
         """Create special categories for uncounted employees.
@@ -409,10 +394,10 @@ class PopulationOES(Population):
             pat = code[0:3]
             filt = detailed[detailed["occ_code"].str.startswith(pat)]
 
-            # Calculate number of employees unaccounted for within the major
+            # calculate number of employees unaccounted for within the major
             # OCC code
             total = int(major[major["occ_code"] == code]["tot_emp"])
-            det_total = np.sum(filt["tot_emp"])
+            det_total = np.sum(filt.astype({"tot_emp": "int"})["tot_emp"])
             delta = total - det_total
 
             if delta > 0:
@@ -426,7 +411,7 @@ class PopulationOES(Population):
 
         return detailed
 
-    def format_output(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _format_output(self, df: pd.DataFrame) -> pd.DataFrame:
         """Format dataframe to fit the model by dropping some columns.
 
         Args:
@@ -438,10 +423,9 @@ class PopulationOES(Population):
         df = df.drop(df[df["tot_emp"] == 0].index)
         df = df.drop(["o_group"], axis=1)
         df = df.reset_index(drop=True)
+        return df.astype({"tot_emp": "int"})
 
-        return df
-
-    def drop_code(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _drop_code(self, df: pd.DataFrame) -> pd.DataFrame:
         """Drop the OCC code from a dataframe.
 
         So that it has the right format for the model.
@@ -453,7 +437,7 @@ class PopulationOES(Population):
 
         return df
 
-    def create_county_df(
+    def _create_county_df(
         self,
         location: Dict,
         oes_df: pd.DataFrame,
@@ -468,28 +452,30 @@ class PopulationOES(Population):
         Returns:
             The processed dataframe
         """
-        # Load in sliced dataframe
-        proportion, df = self.load_county(location, oes_df, code_df, pop_df)
+        # load in sliced dataframe
+        proportion, df = self._load_county(location, oes_df, code_df, pop_df)
 
-        # Split into 'major' and 'detailed' OCC categories
+        # split into 'major' and 'detailed' OCC categories
         major = df[df["o_group"] == "major"].copy()
         detailed = df[df["o_group"] == "detailed"].copy()
 
-        # Some detailed categories don't have information availble - remove
+        # some detailed categories don't have information availble - remove
         # these and place into "Uncounted" category
-        detailed = self.fill_uncounted(major, detailed)
+        detailed = self._fill_uncounted(major, detailed)
 
-        # Adjust 'tot_emp' columns by MSA code proportion
-        detailed["tot_emp"] = detailed["tot_emp"].apply(
-            lambda x: int(x * proportion)
+        # adjust 'tot_emp' columns by MSA code proportion
+        detailed["tot_emp"] = (
+            detailed["tot_emp"]
+            .astype("int")
+            .apply(lambda x: int(x * proportion))
         )
 
-        # Format to fit model
-        detailed = self.format_output(detailed)
+        # format to fit model
+        detailed = self._format_output(detailed)
         detailed.set_index("occ_title", drop=True, inplace=True)
         return detailed
 
-    def create_state_df(
+    def _create_state_df(
         self, location: Dict, oes_df: pd.DataFrame
     ) -> pd.DataFrame:
         """Generate dataframe containing processed OES data by state.
@@ -500,22 +486,21 @@ class PopulationOES(Population):
         Returns:
             The processed dataframe
         """
-        # Load in sliced dataframe
-        df = self.load_state(location, oes_df)
-
+        # load in sliced dataframe
+        df = self._load_state(location, oes_df)
         major = df[df["o_group"] == "major"].copy()
         detailed = df[df["o_group"] == "detailed"].copy()
 
-        # Some detailed categories don't have information available - remove
+        # some detailed categories don't have information available - remove
         # these and place into "Uncounted" category
-        detailed = self.fill_uncounted(major, detailed)
+        detailed = self._fill_uncounted(major, detailed)
 
         # Format to fit model
-        detailed = self.format_output(detailed)
+        detailed = self._format_output(detailed)
         detailed.set_index("occ_title", drop=True, inplace=True)
         return detailed
 
-    def create_country_df(self, oes_df: pd.DataFrame) -> pd.DataFrame:
+    def _create_country_df(self, oes_df: pd.DataFrame) -> pd.DataFrame:
         """Generate dataframe containing processed OES data for US.
 
         Args:
@@ -524,15 +509,15 @@ class PopulationOES(Population):
         Returns:
             The processed dataframe
         """
-        df = self.load_country(oes_df)
+        df = self._load_country(oes_df)
         major = df[df["o_group"] == "major"].copy()
         detailed = df[df["o_group"] == "detailed"].copy()
-        detailed = self.fill_uncounted(major, detailed)
-        detailed = self.format_output(detailed)
+        detailed = self._fill_uncounted(major, detailed)
+        detailed = self._format_output(detailed)
         detailed.set_index("occ_title", drop=True, inplace=True)
         return detailed
 
-    def health_filter(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _health_filter(self, df: pd.DataFrame) -> pd.DataFrame:
         """Return a detailed breakdown of healthcare workers with OCC codes.
 
         Args:
@@ -548,7 +533,7 @@ class PopulationOES(Population):
         ]
         return filt
 
-    def wa_tier2_opt1_filter(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _wa_tier2_opt1_filter(self, df: pd.DataFrame) -> pd.DataFrame:
         """Return a detailed breakdown of Washington tier 2 workers.
 
         Args:
@@ -565,7 +550,7 @@ class PopulationOES(Population):
 
         return filt
 
-    def wa_tier2_opt2_filter(self, df: pd.DataFrame) -> pd.DataFrame:
+    def _wa_tier2_opt2_filter(self, df: pd.DataFrame) -> pd.DataFrame:
         """Return a detailed breakdown of Washington tier 2 workers.
 
         Args:
@@ -603,15 +588,30 @@ class PopulationOES(Population):
 
         return filt
 
-    def set_essential(self, df: pd.DataFrame, config) -> pd.DataFrame:
+    def _wa_public_safety_filter(self, df: pd.DataFrame) -> pd.DataFrame:
+        """Return a detailed breakdown of Washington public safety."""
+        occ_list = [
+            "29-2040",
+            "33-2011",
+            "33-3012",
+            "33-3021",
+            "33-9093",
+            "33-3041",
+            "33-3051",
+        ]
+
+        filt = df[df["occ_code"].isin(occ_list)]
+        return filt
+
+    def _set_wa_sum(self, df: pd.DataFrame, config) -> pd.DataFrame:
+        """Washington group summarization."""
+        pop_level: List = []
+
+    def _set_essential(self, df: pd.DataFrame, config) -> pd.DataFrame:
         """Get population essential levels from the excel model.
 
         Manually slice the dataframe
         """
-        # df.columns = df.iloc[2528]
-        # df = df.iloc[2529:3303]
-        # df = df[["SOC", "Essential (0 lowest)"]]
-
         pop_level: List = []
         df["SOC"] = df["SOC"].apply(datetime_to_code)
         df.reset_index(drop=True, inplace=True)
