@@ -6,7 +6,7 @@ from restart.log import Log
 from restart.model import Model
 from restart.util import set_config
 
-PATH = pathlib.Path(__file__).parent.parent.absolute()
+PATH = pathlib.Path(__file__).parent.absolute()
 
 class RestartModel:
     """Bootstrap a model object in a notebook environment."""
